<?php

namespace Drupal\nginx_proxy_manager_connector\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class NginxProxySettingsForm.
 */
class NginxProxySettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'nginx_proxy_manager_connector.nginxproxysettings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'nginx_proxy_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('nginx_proxy_manager_connector.nginxproxysettings');
    $form['api_base_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Base URL'),
      '#description' => $this->t('Enter the base url for the API calls to Nginx Proxy Manager instance'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('api_base_url'),
    ];
    $form['default_forward_host'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default Forward Host'),
      '#description' => $this->t('Enter the default forward host to be used for the proxy hosts created by the module (Update .env file to modify the value)'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $_ENV['NGINX_PROXY_MANAGER_DEFAULT_FORWARD_HOST'],
      '#disabled' => TRUE,
    ];
    $form['default_forward_host_port'] = [
      '#type' => 'number',
      '#title' => $this->t('Default Forward Host Port'),
      '#description' => $this->t('Enter the default forward host port to be used.'),
      '#default_value' => $config->get('default_forward_host_port'),
    ];
    $form['letsencrypt_email'] = [
      '#type' => 'email',
      '#title' => $this->t('Email for generating LetsEncrypt Certificates'),
      '#description' => $this->t('Enter the email used for managing LetsEncrypt Certificates.'),
      '#default_value' => $config->get('letsencrypt_email'),
    ];
    $form['email_nginx_proxy'] = [
      '#type' => 'email',
      '#title' => $this->t('Email'),
      '#description' =>  $this->t('User credentials of Nginx Proxy Manager (Update .env file to modify the value)'),
      '#disabled' => TRUE,
      '#default_value' => $_ENV['NGINX_PROXY_MANAGER_USER_EMAIL'],
    ];
    $form['password_nginx_proxy'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Password'),
      '#description' =>  $this->t('User credentials of Nginx Proxy Manager (Update .env file to modify the value)'),
      '#disabled' => TRUE,
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $_ENV['NGINX_PROXY_MANAGER_PASSWORD'],
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('nginx_proxy_manager_connector.nginxproxysettings')
      ->set('api_base_url', $form_state->getValue('api_base_url'))
      ->set('default_forward_host_port', $form_state->getValue('default_forward_host_port'))
      ->set('letsencrypt_email', $form_state->getValue('letsencrypt_email'))
      ->save();

  }

}
